Crate dix

Crate dix 

Re-exports

pub use report::DerivationSelectionStatus;
pub use report::DiffReport;
pub use report::PackageDiff;
pub use report::PackageSizeDelta;
pub use report::PathStats;
pub use report::diff_store_snapshots;
pub use report::query_diff_report;
pub use snapshot::StoreSnapshot;
pub use snapshot::query_store_snapshot;
pub use snapshot::query_store_snapshot_with_backend;
pub use store::CommandBackend;

Modules

json
report
snapshot
store
Provides an interface for querying data from the nix store.

Structs

StorePath
A validated store path. Always starts with /nix/store.
Version
A version string with semantic comparison support.
VersionAmount

Enums

DiffStatus
VersionDiff

Functions

write_diff_report
Writes a full diff report to the provided writer.