pub fn write_diff_report( writer: &mut impl Write, report: &DiffReport, ) -> Result<usize, Error>
Writes a full diff report to the provided writer.
Returns the number of package diffs written.
Returns an error if writing to the output fails.