CombinedStoreBackend

Struct CombinedStoreBackend 

pub struct CombinedStoreBackend { /* private fields */ }
combines multiple store backends by falling back to the next one if the current one fails.

Queries try connected backends in order.

Implementations

Source

impl CombinedStoreBackend

pub fn new(backends: Vec<Box<dyn StoreBackend>>) -> Self

pub fn for_correctness(force_correctness: bool) -> Self

pub fn default_fast() -> Self

Returns a backend that is focused on performance and availability.

This first tries the regular sqlite database, then falls back to opening it with immutable=1, and finally falls back to Nix commands.

pub fn default_correct() -> Self

Returns a backend that is focused solely on absolutely guaranteeing correct results if the regular sqlite database cannot be opened.

Note that DATABASE_PATH_IMMUTABLE is not used here, since opening the database can lead to undefined results (also silently with no errors) if the database is actually modified while opened.