Crate dix

Crate dix 

Re-exports

pub use report::DerivationSelectionStatus;
pub use report::DiffReport;
pub use report::PackageDiff;
pub use report::PackageSizeDelta;
pub use report::PathStats;
pub use report::query_diff_report;

Modules

json
report
store
Provides an interface for querying data from the nix store.

Structs

StorePath
A validated store path. Always starts with /nix/store.
Version
A version string with semantic comparison support.
VersionAmount

Enums

DiffStatus
VersionDiff

Functions

write_diff_report
Writes a full diff report to the provided writer.