write_diff_report

Function write_diff_report 

pub fn write_diff_report(
    writer: &mut impl Write,
    report: &DiffReport,
) -> Result<usize, Error>
Writes a full diff report to the provided writer.

Returns

Returns the number of package diffs written.

Errors

Returns an error if writing to the output fails.